#DMIMET
Tools commonly used in Meteorological software that I dont want to replicate all the times

#Documentation:
https://dmit.readthedocs.io/en/latest/

### Docstrings
For the sake of making the documentation as automatic as possible the standard of numpy docstring is followed.
https://numpydoc.readthedocs.io/en/latest/format.html#docstring-standard
This is supported also by sphinx.

The docs is made with sphinx and can be found here:
https://dmit.readthedocs.io/en/latest/
